/*
  Weasel stage 4 filter for the IMAP4 server.
  Sends notification to imapd of the received file.
*/

/* Your stage 4 filter. */
userFilter = ""

/* Debug is 1 - print imapd answers to the screen. */
debug = 1


socketName = "imapd"

parse arg nameFile" "msgFile
if msgFile = "" then
do
  say "This code should be called from Weasel as stage 4 filter."
  return 0
end


/*
   Run user filter
*/

if symbol( "userFilter" ) = "VAR" & userFilter \= "" then
do
  cmd = userFilter || " " || nameFile || " " || msgFile
  if debug = 1 then
    say "[imapStage4] Run: " || cmd

  "@cmd /c " || cmd
  res = rc
  if debug = 1 then
    say "[imapStage4] User filter " || userFilter || " result code: " || res
end
else
  res = 0


/*
   If message was not filtered by the user filter then send request to imapd.
*/

if res < 2 | res == 16 then
do
  slashPos = lastpos( "\", msgFile )
  if slashPos > 1 then
  do
    mboxPath = left( msgFile, slashPos - 1 )

    slashPos = lastpos( "\", mboxPath )
    if slashPos > 1 & mboxPath \= "" then
    if translate( substr( mboxPath, slashPos + 1 ) ) \= "FORWARD" then
    do
      /* Load spam filter and imapd REXX API */

      if RxFuncQuery( "rxsfLoadFuncs" ) == 1 then
      do
        call RxFuncAdd "rxsfLoadFuncs", "rxsf", "rxsfLoadFuncs"
        call rxsfLoadFuncs
      end

      /* Send request to imapd.
         The user home directory (INBOX) will be checked for changes in 3 sec. */

      imapRes = rxsfRequest( socketName, "NWPNOTIFY 3 " || mboxPath )
      if debug = 1 then
        say "[imapStage4] imapd notification result: "imapRes
    end
  end
end

return res
